==> qtjambi-qt3drender-6.2.10-sources.jar: io/qt/qt3d/render/QRenderAspect.java <==
package io.qt.qt3d.render;


/**
 * <p>Class</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qrenderaspect.html">Qt3DRender::QRenderAspect</a></p>
 */
public class QRenderAspect extends io.qt.qt3d.core.QAbstractAspect
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderAspect.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qrenderaspect.html#SubmissionType-enum">Qt3DRender::QRenderAspect::SubmissionType</a></p>
     */
    @io.qt.QtUnlistedEnum
    public enum SubmissionType implements io.qt.QtEnumerator {
        Automatic(0),
        Manual(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private SubmissionType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static SubmissionType resolve(int value) {
            switch (value) {
            case 0: return Automatic;
            case 1: return Manual;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrenderaspect.html#QRenderAspect">Qt3DRender::QRenderAspect::QRenderAspect(QObject*)</a></p>
     */
    public QRenderAspect(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderAspect instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QRenderAspect(io.qt.qt3d.render.QRenderAspect.SubmissionType, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderAspect(io.qt.qt3d.render.QRenderAspect.SubmissionType submissionType) {
        this(submissionType, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrenderaspect.html#QRenderAspect-1">Qt3DRender::QRenderAspect::QRenderAspect(Qt3DRender::QRenderAspect::SubmissionType,QObject*)</a></p>
     */
    public QRenderAspect(io.qt.qt3d.render.QRenderAspect.SubmissionType submissionType, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, submissionType, parent);
    }
    
    private native static void initialize_native(QRenderAspect instance, io.qt.qt3d.render.QRenderAspect.SubmissionType submissionType, io.qt.core.QObject parent);
    
    @Deprecated
    @io.qt.QtUninvokable
    public final java.util.List<java.lang.String> dependencies() throws io.qt.QNoImplementationException {
        return dependencies_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static java.util.List<java.lang.String> dependencies_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderAspect instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.3.3-sources.jar: io/qt/qt3d/render/QRenderAspect.java <==
package io.qt.qt3d.render;


/**
 * <p>Class</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qrenderaspect.html">Qt3DRender::QRenderAspect</a></p>
 */
public class QRenderAspect extends io.qt.qt3d.core.QAbstractAspect
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderAspect.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qrenderaspect.html#SubmissionType-enum">Qt3DRender::QRenderAspect::SubmissionType</a></p>
     */
    @io.qt.QtUnlistedEnum
    public enum SubmissionType implements io.qt.QtEnumerator {
        Automatic(0),
        Manual(1);

        private SubmissionType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static SubmissionType resolve(int value) {
            switch (value) {
            case 0: return Automatic;
            case 1: return Manual;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrenderaspect.html#QRenderAspect">Qt3DRender::QRenderAspect::QRenderAspect(QObject*)</a></p>
     */
    public QRenderAspect(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderAspect instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QRenderAspect(io.qt.qt3d.render.QRenderAspect.SubmissionType, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderAspect(io.qt.qt3d.render.QRenderAspect.SubmissionType submissionType) {
        this(submissionType, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrenderaspect.html#QRenderAspect-1">Qt3DRender::QRenderAspect::QRenderAspect(Qt3DRender::QRenderAspect::SubmissionType,QObject*)</a></p>
     */
    public QRenderAspect(io.qt.qt3d.render.QRenderAspect.SubmissionType submissionType, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, submissionType, parent);
    }
    
    private native static void initialize_native(QRenderAspect instance, io.qt.qt3d.render.QRenderAspect.SubmissionType submissionType, io.qt.core.QObject parent);
    
    @Deprecated
    @io.qt.QtUninvokable
    public final java.util.List<java.lang.String> dependencies() throws io.qt.QNoImplementationException {
        return dependencies_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static java.util.List<java.lang.String> dependencies_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderAspect instance, QDeclarativeConstructor constructor);
    
}
